@@ -10,7 +10,6 @@ from mutagen import File
 from mutagen.id3 import ID3, APIC
 from mutagen.easyid3 import EasyID3
 from mutagen.mp3 import MP3
-from tqdm import tqdm
 
 from .ProgressHandler import BaseProgressHandler, DefaultProgressHandler
 
@@ -369,8 +368,8 @@ class Deezer:
                     return (url, key)
 
     def download_track(self, track, download_dir, quality=None, fallback=True, filename=None, renew=False,
-                       with_metadata=True, with_lyrics=True, tag_separator=", ",
-                       progress_handler: BaseProgressHandler = DefaultProgressHandler, **kwargs):
+                       with_metadata=True, with_lyrics=True, tag_separator=", ", show_messages=True,
+                       progress_handler: BaseProgressHandler = None, **kwargs):
         """Downloads the given track
 
         Arguments:
@@ -428,7 +427,8 @@ class Deezer:
 
         util.create_folders(download_dir)
 
-        print("Starting download of:", title)
+        if show_messages:
+            print("Starting download of:", title)
 
         res = self.session.get(url, cookies=self.get_cookies(), stream=True)
         chunk_size = 2048
@@ -436,24 +436,25 @@ class Deezer:
         i = 0
 
         data_iter = res.iter_content(chunk_size)
-        
-        if not progress_handler:
-            progress_handler = DefaultProgressHandler
 
-        _progress_handler = progress_handler(data_iter,
-                                             title, quality_key, total_filesize, chunk_size)
+        if not progress_handler:
+            progress_handler = DefaultProgressHandler()
+
+        progress_handler.initialize(data_iter, title, quality_key, total_filesize,
+                                    chunk_size, track_id=track["SNG_ID"])
 
         with open(download_path, "wb") as f:
-            f.seek(_progress_handler.size_downloaded)
+            f.seek(0)
 
             for chunk in data_iter:
-                _progress_handler.current_chunk_size = len(chunk)
+                current_chunk_size = len(chunk)
 
                 if i % 3 > 0:
                     f.write(chunk)
                 elif len(chunk) < chunk_size:
                     f.write(chunk)
-                    _progress_handler.update()
+                    progress_handler.update(
+                        track_id=track["SNG_ID"], current_chunk_size=current_chunk_size)
                     break
                 else:
                     cipher = Cipher(algorithms.Blowfish(blowfish_key),
@@ -466,14 +467,12 @@ class Deezer:
                         chunk) + decryptor.finalize()
                     f.write(dec_data)
 
-                    _progress_handler.current_chunk_size = len(dec_data)
+                    current_chunk_size = len(dec_data)
 
                 i += 1
 
-                _progress_handler.size_downloaded += chunk_size
-                _progress_handler.update()
-
-        _progress_handler.close()
+                progress_handler.update(
+                    track_id=track["SNG_ID"], current_chunk_size=current_chunk_size)
 
         if with_metadata:
             if ext.lower() == ".flac":
@@ -485,7 +484,10 @@ class Deezer:
             lyrics_path = path.join(download_dir, filename[:-len(ext)])
             self.save_lyrics(lyric_data, lyrics_path)
 
-        print("Track downloaded to:", download_path)
+        if show_messages:
+            print("Track downloaded to:", download_path)
+
+        progress_handler.close(track_id=track["SNG_ID"], total_filesize=total_filesize)
 
     def get_tracks(self, track_ids):
         """Gets the list of the tracks that corresponds with the given {track_ids}
