@@ -1,6 +1,8 @@
 from . import util
 from . import exceptions
 from . import constants
+from . import ProgressHandler
 from .Deezer import Deezer
+from .Downloader import Downloader
 
 name = "PyDeezer"
